@@ -11,7 +11,6 @@ from pydantic import root_validator
 
 @record_class
 class EltInterface(UaInterface):
-    _auto_build_object = True
 
     Node = EltNode
     Rpc = EltRpc
@@ -26,8 +25,8 @@ class EltInterface(UaInterface):
         self.fits_key = fits_key
     
     @classmethod
-    def new_args(cls, parent, config):
-        d = super().new_args(parent, config)
+    def new_args(cls, parent, name, config):
+        d = super().new_args(parent, name, config)
         d.update(fits_key = parent.fits_key)
         return d
          
