@@ -3,7 +3,7 @@ from pydevmgr_elt.base import EltDevice,  GROUP
 from pydevmgr_elt.devices.motor import Motor
 from pydevmgr_elt.devices.drot.stat import MODE
 from pydevmgr_elt.base.tools import _inc, enum_group, enum_txt
-from pydevmgr_ua import Int16
+from pydevmgr_ua import UaInt16
 
 from enum import Enum
 Base = Motor.Rpcs
@@ -12,14 +12,25 @@ R = Base.Rpc # Base Node
 RC = R.Config
 RD = Defaults[RC] # this typing var says that it is a Rpc object holding default values 
 
-# RPC_ERROR are iddentical then Motor 
+to_int16 = UaInt16()
+
+# RPC_ERROR are iddentical to Motor 
+
+class TRACK_MODE(int, Enum):
+    SKY  = MODE.SKY.value 
+    ELEV = MODE.ELEV.value 
+        
 
 def mode_parser(mode):
     if isinstance(mode, str):
-        if mode not in ['SKY', 'ELEV']:
-            raise ValueError('tracking mode must be one of SKY or ELEV got %r'%mode)
-        mode = getattr(MODE, mode)
-    return Int16(mode)
+        try:
+            mode = getattr( TRACK_MODE, mode)
+        except AttributeError:
+            choices = ",".join(str(m) for m in  TRACK_MODE)
+            raise ValueError(f'tracking mode must be one of {choices} got %r'%mode)
+    else:
+        mode = TRACK_MODE(mode)
+    return to_int16(mode)
 
 
 class DrotRpcs(Base):
