@@ -99,14 +99,41 @@ class DrotStat(Base):
         # all configured node will be accessible by the Interface
 
         # All other nodes are similar to Drot
-        state:            ND = NC (suffix="sm.nState")
-        substate:         ND = NC (suffix="sm.nSubstate")
-        initialised:      ND = NC (suffix="bInitialised")
-        track_mode:       ND = NC (suffix="nMode")
-        alpha:            ND = NC (suffix="apparent.alpha")
-        delta:            ND = NC (suffix="apparent.delta")
-        angle_on_sky:     ND = NC (suffix="lrAngleOnSky")
+        state:            ND = NC (suffix="stat.sm.nState")
+        substate:         ND = NC (suffix="stat.sm.nSubstate")
+        initialised:      ND = NC (suffix="stat.bInitialised")
+        track_mode:       ND = NC (suffix="stat.nMode")
+        alpha:            ND = NC (suffix="stat.apparent.alpha")
+        delta:            ND = NC (suffix="stat.apparent.delta")
+        angle_on_sky:     ND = NC (suffix="stat.lrAngleOnSky")
         
+        axis_brake: ND = NC(suffix='motor.stat.bBrakeActive' )
+        axis_enable: ND = NC(suffix='motor.stat.bEnabled' )
+        axis_info_data1: ND = NC(suffix='motor.stat.nInfoData1' )
+        axis_info_data2: ND = NC(suffix='motor.stat.nInfoData2' )
+        axis_inposition: ND = NC(suffix='motor.stat.bInPosition' )
+        axis_lock: ND = NC(suffix='motor.stat.bLock' )
+        axis_ready: ND = NC(suffix='motor.stat.bAxisReady' )
+        backlash_step: ND = NC(suffix='motor.stat.nBacklashStep' )
+        error_code: ND = NC(suffix='motor.stat.nErrorCode' )
+        init_action: ND = NC(suffix='motor.stat.nInitAction' )
+        init_step: ND = NC(suffix='motor.stat.nInitStep' )
+        local: ND = NC(suffix='motor.stat.bLocal' )
+        mode: ND = NC(suffix='motor.stat.nMode' )
+        pos_actual: ND = NC(suffix='motor.stat.lrPosActual' )
+        pos_error: ND = NC(suffix='motor.stat.lrPosError' )
+        pos_target: ND = NC(suffix='motor.stat.lrPosTarget' )
+        scale_factor: ND = NC(suffix='motor.stat.lrScaleFactor' )
+        signal_index: ND = NC(suffix='motor.stat.signals[3].bActive' )
+        signal_lhw: ND = NC(suffix='motor.stat.signals[1].bActive' )
+        signal_lstop: ND = NC(suffix='motor.stat.signals[0].bActive' )
+        signal_ref: ND = NC(suffix='motor.stat.signals[2].bActive' )
+        signal_uhw: ND = NC(suffix='motor.stat.signals[4].bActive' )
+        signal_ustop: ND = NC(suffix='motor.stat.signals[5].bActive' )
+        state: ND = NC(suffix='motor.stat.nState' )
+        status: ND = NC(suffix='motor.stat.nStatus' )
+        substate: ND = NC(suffix='motor.stat.nSubstate' )
+        vel_actual: ND = NC(suffix='motor.stat.lrVelActual' )
 
 
     # We can add some nodealias to compute some stuff on the fly 
